@@ -24,10 +24,11 @@ def get_file_object(response):
     }
 
 
-def parse_attachment_output(response, output, manifest):
-    if 'file' not in manifest['output']:
+def parse_attachment_output(response, manifest):
+    if 'file' not in manifest['output'].get('properties', {}):
         return
+
     if manifest['output']['properties']['file']['type'] == 'array':
-        output['file'] = [get_file_object(response)]
+        return [get_file_object(response)]
     else:
-        output['file'] = get_file_object(response)
+        return get_file_object(response)
